lookahead

Function lookahead 

pub fn lookahead(
    state: &mut LuaState,
    ls: &mut LexState,
) -> Result<i32, LuaError>
Peek at the next token without consuming the current one.

The lookahead token is cached in ls.lookahead and returned. Only one token of lookahead is supported; calling this twice without an intervening next is a logic error (asserted in debug builds).

C source


//   lua_assert(ls->lookahead.token == TK_EOS);
//   ls->lookahead.token = llex(ls, &ls->lookahead.seminfo);
//   return ls->lookahead.token;
// }